# Changelog

## 0.17.1 (2025-11-12)

Full Changelog: [v0.17.0...v0.17.1](https://github.com/premAI-io/prem-py-sdk/compare/v0.17.0...v0.17.1)

## 0.17.0 (2025-11-12)

Full Changelog: [v0.16.0...v0.17.0](https://github.com/premAI-io/prem-py-sdk/compare/v0.16.0...v0.17.0)

### Features

* **api:** api update ([739a8d7](https://github.com/premAI-io/prem-py-sdk/commit/739a8d7fa6b045c6e9c30fd7510245772344d50a))

## 0.16.0 (2025-11-12)

Full Changelog: [v0.15.4...v0.16.0](https://github.com/premAI-io/prem-py-sdk/compare/v0.15.4...v0.16.0)

### Features

* **api:** api update ([61861df](https://github.com/premAI-io/prem-py-sdk/commit/61861df8576ea457eede8dd8f03218bc6e34c415))
* **api:** manual updates ([7dc859c](https://github.com/premAI-io/prem-py-sdk/commit/7dc859cd5e92af76bdc200fcb68da5ca0ac1548c))


### Bug Fixes

* compat with Python 3.14 ([9c232f5](https://github.com/premAI-io/prem-py-sdk/commit/9c232f5bd19c653ddf8031fdba1847393ab2ff3a))
* **compat:** update signatures of `model_dump` and `model_dump_json` for Pydantic v1 ([9d70dd2](https://github.com/premAI-io/prem-py-sdk/commit/9d70dd2f7b8db1bff67c32f22147cb1858b8ea71))


### Chores

* **package:** drop Python 3.8 support ([fdef2f0](https://github.com/premAI-io/prem-py-sdk/commit/fdef2f084a745daf108f1fd4879a8bf933e1062d))

## 0.15.4 (2025-11-05)

Full Changelog: [v0.15.3...v0.15.4](https://github.com/premAI-io/prem-py-sdk/compare/v0.15.3...v0.15.4)

### Bug Fixes

* **client:** close streams without requiring full consumption ([b011a79](https://github.com/premAI-io/prem-py-sdk/commit/b011a79f54f95e54d4946c03b0309493351c49d1))


### Chores

* **internal/tests:** avoid race condition with implicit client cleanup ([c623c95](https://github.com/premAI-io/prem-py-sdk/commit/c623c9576287e80a044354d76c88cfe54486463a))
* **internal:** grammar fix (it's -&gt; its) ([4b7d8e2](https://github.com/premAI-io/prem-py-sdk/commit/4b7d8e2fca3975b1a2e420b9a8c084fa6c594a15))

## 0.15.3 (2025-10-18)

Full Changelog: [v0.15.2...v0.15.3](https://github.com/premAI-io/prem-py-sdk/compare/v0.15.2...v0.15.3)

### Chores

* bump `httpx-aiohttp` version to 0.1.9 ([23c1654](https://github.com/premAI-io/prem-py-sdk/commit/23c16544deed1e0ae0a09ceaabb16f52314b6927))

## 0.15.2 (2025-10-11)

Full Changelog: [v0.15.1...v0.15.2](https://github.com/premAI-io/prem-py-sdk/compare/v0.15.1...v0.15.2)

### Chores

* **internal:** detect missing future annotations with ruff ([2a012e8](https://github.com/premAI-io/prem-py-sdk/commit/2a012e8410627f9249ae4ac1cd1ae5dea419df76))

## 0.15.1 (2025-09-20)

Full Changelog: [v0.15.0...v0.15.1](https://github.com/premAI-io/prem-py-sdk/compare/v0.15.0...v0.15.1)

### Chores

* do not install brew dependencies in ./scripts/bootstrap by default ([7696c06](https://github.com/premAI-io/prem-py-sdk/commit/7696c06da377622ef47ee89049c06171bd2e2baf))
* **internal:** update pydantic dependency ([54b0be2](https://github.com/premAI-io/prem-py-sdk/commit/54b0be259cc19f17fb2f8055a6a31c3008e9b7d4))
* **types:** change optional parameter type from NotGiven to Omit ([cbef005](https://github.com/premAI-io/prem-py-sdk/commit/cbef005747acd51dcbef8edf7009cdc1e12c2b9e))

## 0.15.0 (2025-09-09)

Full Changelog: [v0.14.4...v0.15.0](https://github.com/premAI-io/prem-py-sdk/compare/v0.14.4...v0.15.0)

### Features

* **api:** api update ([c9f482c](https://github.com/premAI-io/prem-py-sdk/commit/c9f482ccca0c5c5086a0991b93b45c0ae8e7e421))
* improve future compat with pydantic v3 ([db8be29](https://github.com/premAI-io/prem-py-sdk/commit/db8be29cc21f0c9c5b2b4c6f95030d12e7a89043))
* **types:** replace List[str] with SequenceNotStr in params ([3a36862](https://github.com/premAI-io/prem-py-sdk/commit/3a368626be70bd089510c0ea57e56fc2d0f6542f))


### Chores

* **internal:** move mypy configurations to `pyproject.toml` file ([c660402](https://github.com/premAI-io/prem-py-sdk/commit/c660402898cad51dbd647ececb7424c69ff0bec3))
* **tests:** simplify `get_platform` test ([499afb7](https://github.com/premAI-io/prem-py-sdk/commit/499afb7161ef3c0fafe6917c4c005e39fa8b9c7e))

## 0.14.4 (2025-08-30)

Full Changelog: [v0.14.3...v0.14.4](https://github.com/premAI-io/prem-py-sdk/compare/v0.14.3...v0.14.4)

### Chores

* **internal:** add Sequence related utils ([59f79ad](https://github.com/premAI-io/prem-py-sdk/commit/59f79ad6928c01fc26ee0f3ef22985f5a75f1f56))

## 0.14.3 (2025-08-27)

Full Changelog: [v0.14.2...v0.14.3](https://github.com/premAI-io/prem-py-sdk/compare/v0.14.2...v0.14.3)

### Bug Fixes

* avoid newer type syntax ([a8d8e7d](https://github.com/premAI-io/prem-py-sdk/commit/a8d8e7d6eb26aecfd124d03b4aee8fa456f9d9fa))


### Chores

* **internal:** update pyright exclude list ([77a29fb](https://github.com/premAI-io/prem-py-sdk/commit/77a29fbee1fdfe00bd0cea4307f27f42aab9caa9))

## 0.14.2 (2025-08-26)

Full Changelog: [v0.14.1...v0.14.2](https://github.com/premAI-io/prem-py-sdk/compare/v0.14.1...v0.14.2)

### Chores

* **internal:** change ci workflow machines ([a44432a](https://github.com/premAI-io/prem-py-sdk/commit/a44432adcf6b00315433ae296f2c2479d0832cac))

## 0.14.1 (2025-08-22)

Full Changelog: [v0.14.0...v0.14.1](https://github.com/premAI-io/prem-py-sdk/compare/v0.14.0...v0.14.1)

### Chores

* update github action ([e9a157a](https://github.com/premAI-io/prem-py-sdk/commit/e9a157a5c0ab3dd6027acda44f231409317f9d44))

## 0.14.0 (2025-08-21)

Full Changelog: [v0.13.0...v0.14.0](https://github.com/premAI-io/prem-py-sdk/compare/v0.13.0...v0.14.0)

### Features

* **api:** api update ([baad631](https://github.com/premAI-io/prem-py-sdk/commit/baad631026a334145aabc29c3f4935cd25197f70))

## 0.13.0 (2025-08-20)

Full Changelog: [v0.12.0...v0.13.0](https://github.com/premAI-io/prem-py-sdk/compare/v0.12.0...v0.13.0)

### Features

* **api:** api update ([1c32a32](https://github.com/premAI-io/prem-py-sdk/commit/1c32a3239d727aea532fb910b38e76862367e834))

## 0.12.0 (2025-08-14)

Full Changelog: [v0.11.1...v0.12.0](https://github.com/premAI-io/prem-py-sdk/compare/v0.11.1...v0.12.0)

### Features

* **api:** api update ([88e01ac](https://github.com/premAI-io/prem-py-sdk/commit/88e01acb8ec438c519cb030aa5b7d45ba162842f))

## 0.11.1 (2025-08-13)

Full Changelog: [v0.11.0...v0.11.1](https://github.com/premAI-io/prem-py-sdk/compare/v0.11.0...v0.11.1)

### Features

* **api:** api update ([047a9de](https://github.com/premAI-io/prem-py-sdk/commit/047a9defa80c0317713ab6026f55c25a3bbc7e07))

## 0.11.0 (2025-08-13)

Full Changelog: [v0.10.4...v0.11.0](https://github.com/premAI-io/prem-py-sdk/compare/v0.10.4...v0.11.0)

### Features

* **api:** api update ([46ddd5e](https://github.com/premAI-io/prem-py-sdk/commit/46ddd5e14eb02c9f101a6e027839e089163d0b66))

## 0.10.4 (2025-08-13)

Full Changelog: [v0.10.3...v0.10.4](https://github.com/premAI-io/prem-py-sdk/compare/v0.10.3...v0.10.4)

### Chores

* **internal:** codegen related update ([952be6c](https://github.com/premAI-io/prem-py-sdk/commit/952be6c61093300c6a3585ce6049e34bc60a7460))
* **internal:** update comment in script ([f335375](https://github.com/premAI-io/prem-py-sdk/commit/f33537559d1bfddd86c2569c966d35b587c5fda3))
* update @stainless-api/prism-cli to v5.15.0 ([c58ea25](https://github.com/premAI-io/prem-py-sdk/commit/c58ea25a9167416ed1ac619b80e6cc793b838ad1))

## 0.10.3 (2025-08-07)

Full Changelog: [v0.10.1...v0.10.3](https://github.com/premAI-io/prem-py-sdk/compare/v0.10.1...v0.10.3)

### Chores

* **internal:** fix ruff target version ([95b53df](https://github.com/premAI-io/prem-py-sdk/commit/95b53df00989f49366a13b276bb1e63bbe9665f1))

## 0.10.1 (2025-07-30)

Full Changelog: [v0.9.3...v0.10.1](https://github.com/premAI-io/prem-py-sdk/compare/v0.9.3...v0.10.1)

### Features

* **api:** api update ([87f33b0](https://github.com/premAI-io/prem-py-sdk/commit/87f33b00ef534fbe704aa598efbe003830ce8934))

## 0.9.3 (2025-07-26)

Full Changelog: [v0.9.2...v0.9.3](https://github.com/premAI-io/prem-py-sdk/compare/v0.9.2...v0.9.3)

### Chores

* **project:** add settings file for vscode ([d49b987](https://github.com/premAI-io/prem-py-sdk/commit/d49b987a2c7e5255425d11fa21212dbc3344b341))

## 0.9.2 (2025-07-23)

Full Changelog: [v0.9.1...v0.9.2](https://github.com/premAI-io/prem-py-sdk/compare/v0.9.1...v0.9.2)

### Features

* clean up environment call outs ([2078d59](https://github.com/premAI-io/prem-py-sdk/commit/2078d5999f05bfbb634356157da7ad2f3c7ef187))


### Bug Fixes

* **parsing:** ignore empty metadata ([fa62b20](https://github.com/premAI-io/prem-py-sdk/commit/fa62b209f6b94610df1b0aa5a883c9b223defe5c))
* **parsing:** parse extra field types ([90792e4](https://github.com/premAI-io/prem-py-sdk/commit/90792e43d3dabbcfaac2da7c1e43baea736eb18a))

## 0.9.1 (2025-07-15)

Full Changelog: [v0.9.0...v0.9.1](https://github.com/premAI-io/prem-py-sdk/compare/v0.9.0...v0.9.1)

### Bug Fixes

* **client:** don't send Content-Type header on GET requests ([7095952](https://github.com/premAI-io/prem-py-sdk/commit/709595236094fffedebfee484f57250a3314a0cb))
* **parsing:** correctly handle nested discriminated unions ([2418a63](https://github.com/premAI-io/prem-py-sdk/commit/2418a6385280b5da2a729fa9c3f5925fdf2458f5))


### Chores

* **internal:** bump pinned h11 dep ([ec109a0](https://github.com/premAI-io/prem-py-sdk/commit/ec109a03a8519ae7747833e9b63a7a7f960769b9))
* **internal:** codegen related update ([63855ad](https://github.com/premAI-io/prem-py-sdk/commit/63855adc39578d040ade886d44586af20515f093))
* **package:** mark python 3.13 as supported ([4547461](https://github.com/premAI-io/prem-py-sdk/commit/4547461519547d0b1d917ddc59da4e27f6a97796))
* **readme:** fix version rendering on pypi ([c92e96c](https://github.com/premAI-io/prem-py-sdk/commit/c92e96cbb7ae109af8f4520c7c781ba72b890eda))

## 0.9.0 (2025-07-14)

Full Changelog: [v0.8.2...v0.9.0](https://github.com/premAI-io/prem-py-sdk/compare/v0.8.2...v0.9.0)

### Features

* **api:** manual updates ([e3d45d1](https://github.com/premAI-io/prem-py-sdk/commit/e3d45d1ee84ad9a3266f90043d487b5c57e7bdfd))

## 0.8.2 (2025-07-01)

Full Changelog: [v0.8.1...v0.8.2](https://github.com/premAI-io/prem-py-sdk/compare/v0.8.1...v0.8.2)

### Features

* **api:** manual updates ([7445ee8](https://github.com/premAI-io/prem-py-sdk/commit/7445ee8f163ddc6f6206b396d548e902df84cc87))

## 0.8.1 (2025-07-01)

Full Changelog: [v0.8.0...v0.8.1](https://github.com/premAI-io/prem-py-sdk/compare/v0.8.0...v0.8.1)

### Features

* **api:** manual updates ([1cd0282](https://github.com/premAI-io/prem-py-sdk/commit/1cd028216ffd5c6dcffeacd38c9a9f7c7a541414))

## 0.8.0 (2025-07-01)

Full Changelog: [v0.7.0...v0.8.0](https://github.com/premAI-io/prem-py-sdk/compare/v0.7.0...v0.8.0)

### Features

* **api:** manual updates ([ef4cd2c](https://github.com/premAI-io/prem-py-sdk/commit/ef4cd2c826fe8d74eb87efc4b3efbe2d398fa856))

## 0.7.0 (2025-07-01)

Full Changelog: [v0.5.0...v0.7.0](https://github.com/premAI-io/prem-py-sdk/compare/v0.5.0...v0.7.0)

### Features

* **api:** api update ([8cf9df5](https://github.com/premAI-io/prem-py-sdk/commit/8cf9df5b620a1985428395a474caedf10643a9c4))

## 0.5.0 (2025-07-01)

Full Changelog: [v0.4.4...v0.5.0](https://github.com/premAI-io/prem-py-sdk/compare/v0.4.4...v0.5.0)

### Features

* **api:** api update ([3a3815f](https://github.com/premAI-io/prem-py-sdk/commit/3a3815f059537cca536698dc12fa274d6108d684))
* **client:** add support for aiohttp ([4485537](https://github.com/premAI-io/prem-py-sdk/commit/4485537c514bd172a389a5db7057114c6fa56d60))


### Bug Fixes

* **ci:** correct conditional ([d48634d](https://github.com/premAI-io/prem-py-sdk/commit/d48634de614b3bb559c74895a0983c5ba1c5e7de))
* **ci:** release-doctor — report correct token name ([ba48bbe](https://github.com/premAI-io/prem-py-sdk/commit/ba48bbe0f25ffa5c125c7058bf02413d8e73c0a3))


### Chores

* **ci:** only run for pushes and fork pull requests ([fee01c6](https://github.com/premAI-io/prem-py-sdk/commit/fee01c6e5e919c831f19235fd4a4a4cffd84cc2e))
* **tests:** skip some failing tests on the latest python versions ([414cb9c](https://github.com/premAI-io/prem-py-sdk/commit/414cb9c72427bb6636888c14687a6f1d83be689c))


### Documentation

* **client:** fix httpx.Timeout documentation reference ([847aa47](https://github.com/premAI-io/prem-py-sdk/commit/847aa47046f53ebeb53081268d215f2f22c460c4))

## 0.4.4 (2025-06-18)

Full Changelog: [v0.4.3...v0.4.4](https://github.com/premAI-io/prem-py-sdk/compare/v0.4.3...v0.4.4)

### Bug Fixes

* **tests:** fix: tests which call HTTP endpoints directly with the example parameters ([5e1737b](https://github.com/premAI-io/prem-py-sdk/commit/5e1737b22939aa55341d81f0fcc4d5001403cab5))


### Chores

* **ci:** enable for pull requests ([2cf7744](https://github.com/premAI-io/prem-py-sdk/commit/2cf77447fd943ce5a483bd09a4a2838d13f15ed0))
* **readme:** update badges ([08872b9](https://github.com/premAI-io/prem-py-sdk/commit/08872b9fd473155015e9a6513d9412e57b60141f))

## 0.4.3 (2025-06-17)

Full Changelog: [v0.4.2...v0.4.3](https://github.com/premAI-io/prem-py-sdk/compare/v0.4.2...v0.4.3)

### Chores

* **internal:** update conftest.py ([0e29404](https://github.com/premAI-io/prem-py-sdk/commit/0e2940456bee5c1c8a5aaa2de3effb99681447cc))
* **tests:** add tests for httpx client instantiation & proxies ([dfa6bc3](https://github.com/premAI-io/prem-py-sdk/commit/dfa6bc368ebf2202af576b74133ee627b20c94f3))

## 0.4.2 (2025-06-13)

Full Changelog: [v0.4.1...v0.4.2](https://github.com/premAI-io/prem-py-sdk/compare/v0.4.1...v0.4.2)

### Bug Fixes

* **client:** correctly parse binary response | stream ([2ae4daf](https://github.com/premAI-io/prem-py-sdk/commit/2ae4dafcbf83a20b07a6299112c4ad20960ee90b))


### Chores

* **tests:** run tests in parallel ([92be66f](https://github.com/premAI-io/prem-py-sdk/commit/92be66f7ca6979dc7d21b99ba39c758b2ad07f3c))

## 0.4.1 (2025-06-10)

Full Changelog: [v0.0.2...v0.4.1](https://github.com/premAI-io/prem-py-sdk/compare/v0.0.2...v0.4.1)

### Bug Fixes

* trigger release ([7f27fce](https://github.com/premAI-io/prem-py-sdk/commit/7f27fcec2259676ab3554b9c54814d49651ce67f))

## 0.0.2 (2025-06-03)

Full Changelog: [v1.2.0...v0.0.2](https://github.com/premAI-io/prem-py-sdk/compare/v1.2.0...v0.0.2)

### Features

* **client:** add follow_redirects request option ([fa4bc07](https://github.com/premAI-io/prem-py-sdk/commit/fa4bc070a8346b36bf7f615847ff80f869dc1be3))


### Chores

* **docs:** remove reference to rye shell ([976a220](https://github.com/premAI-io/prem-py-sdk/commit/976a220a2e8ef966fce0e77129d44a5773e11047))
